@@ -6,6 +6,7 @@
 package Debian::Debhelper::Buildsystem::gradle;
 
 use strict;
+use Dpkg::Control;
 use base 'Debian::Debhelper::Buildsystem';
 
 sub DESCRIPTION {
@@ -20,7 +21,10 @@ sub check_auto_buildable {
 sub new {
 	my $class=shift;
 	my $this=$class->SUPER::new(@_);
-	
+
+	my $control = Dpkg::Control->new(type => CTRL_INFO_SRC);
+	$control->load("$this->{cwd}/debian/control");
+
 	@{$this->{gradle_cmd}} = ("gradle",
 		"--info",
 		"--console", "plain",
@@ -31,6 +35,7 @@ sub new {
 		"--gradle-user-home", ".gradle",
 		"-Duser.home=.",
 		"-Duser.name=debian",
+		"-Ddebian.package=$control->{Source}",
 	#	"--init-script", "/usr/share/gradle-debian-helper/init.gradle",
 		);	
 
@@ -62,6 +67,7 @@ sub clean {
 	my $this=shift;
 
 	$this->doit_in_builddir("find . -wholename .*build/tmp | xargs echo | sed -e 's^build/tmp^build^g' | xargs rm -Rf");
+	$this->doit_in_builddir("find . -wholename .*build/debian | xargs echo | sed -e 's^build/tmp^build^g' | xargs rm -Rf");
 	$this->doit_in_builddir("rm", "-Rf", "$this->{cwd}/.gradle", "$this->{cwd}/buildSrc/.gradle", ".m2");
 }
 
